@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2001 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
@@ -20,6 +20,10 @@
  * @APPLE_LICENSE_HEADER_END@
  */
 
+//
+//	Includes
+//
+
 // General OS Services header files
 #include <libkern/OSByteOrder.h>
 
@@ -30,6 +34,11 @@
 
 #include <IOKit/scsi-commands/IOSCSIPeripheralDeviceNub.h>
 
+
+//
+//	Macros
+//
+
 // Macros for printing debugging information
 #if (USB_MASS_STORAGE_DEBUG == 1)
 #define STATUS_LOG(x)	IOLog x
@@ -46,17 +55,28 @@
 
 OSDefineMetaClassAndStructors( IOUSBMassStorageClass, IOSCSIProtocolServices )
 
+
+//
+//	 init - Called at initialization time							   [PUBLIC]
+//
+
 bool 
 IOUSBMassStorageClass::init( OSDictionary * propTable )
 {
     if( super::init( propTable ) == false)
     {
-        return false;
+		return false;
     }
 
     return true;
 }
 
+
+//
+//	 start - Called at services start time	(after successful matching)
+//																	   [PUBLIC]
+//
+
 bool 
 IOUSBMassStorageClass::start( IOService * provider )
 {
@@ -77,7 +97,7 @@ IOUSBMassStorageClass::start( IOService * provider )
     SetInterfaceReference( OSDynamicCast( IOUSBInterface, provider) );
     if ( GetInterfaceReference() == NULL )
     {
-    	STATUS_LOG(("%s: the provider is not an IOUSBInterface object\n", 
+    	STATUS_LOG(("%s: the provider is not an IOUSBInterface object\n",
     				getName()));
     	// If our provider is not a IOUSBInterface object, return false
     	// to indicate that the object could not be correctly 
@@ -264,6 +284,11 @@ abortStart:
     return false;
 }
 
+
+//
+//	 stop - Called at stop time								   [PUBLIC]
+//
+
 void 
 IOUSBMassStorageClass::stop(IOService * provider)
 {
@@ -281,6 +306,10 @@ IOUSBMassStorageClass::stop(IOService * provider)
 }
 
 
+//
+//	 free - Called by IOKit to free any resources.					   [PUBLIC]
+//
+
 void
 IOUSBMassStorageClass::free ( void )
 {
@@ -308,6 +337,10 @@ IOUSBMassStorageClass::free ( void )
 }
 
 
+//
+//	 message - Called by IOKit to deliver messages.				   [PUBLIC]
+//
+
 IOReturn
 IOUSBMassStorageClass::message( UInt32 type, IOService * provider, void * argument )
 {
@@ -369,6 +402,11 @@ IOUSBMassStorageClass::message( UInt32 type, IOService * provider, void * argume
 	return result;
 }
 
+
+//
+//	 BeginProvidedServices											[PROTECTED]
+//
+
 bool	
 IOUSBMassStorageClass::BeginProvidedServices( void )
 {
@@ -453,8 +491,19 @@ IOUSBMassStorageClass::BeginProvidedServices( void )
 			
 			if ( nub->attach( this ) == false )
 			{
-				// panic since the nub can't attach
-				PANIC_NOW(( "IOUSBMassStorageClass::CreatePeripheralDeviceNubForLUN unable to attach nub" ));
+#if 0
+				if ( isInactive() == false )
+				{
+#endif
+					// panic since the nub can't attach and we are active
+					PANIC_NOW(( "IOUSBMassStorageClass::CreatePeripheralDeviceNubForLUN unable to attach nub" ));
+#if 0
+				}
+				
+				// Release our nub before we return so we don't leak...
+				nub->release();
+#endif				
+				// We didn't attach so we should return false.
 				return false;
 			}
 						
@@ -477,14 +526,27 @@ IOUSBMassStorageClass::BeginProvidedServices( void )
 	return true;
 }
 
+
+//
+//	 EndProvidedServices											[PROTECTED]
+//
+
 bool	
 IOUSBMassStorageClass::EndProvidedServices( void )
 {
 	return true;
 }
 
+
 #pragma mark -
-#pragma mark CDB Transport Methods
+#pragma mark *** CDB Transport Methods ***
+#pragma mark -
+
+
+//
+//	 SendSCSICommand												[PROTECTED]
+//
+
 bool 
 IOUSBMassStorageClass::SendSCSICommand( 	
 									SCSITaskIdentifier 			request, 
@@ -566,7 +628,12 @@ IOUSBMassStorageClass::SendSCSICommand(
 	return true;
 }
 
-void 
+
+//
+//	 CompleteSCSICommand											[PROTECTED]
+//
+
+void
 IOUSBMassStorageClass::CompleteSCSICommand( SCSITaskIdentifier request, IOReturn status )
 {
 	fBulkOnlyCommandStructInUse = false;
@@ -582,7 +649,12 @@ IOUSBMassStorageClass::CompleteSCSICommand( SCSITaskIdentifier request, IOReturn
 	}
 }
 
-SCSIServiceResponse 
+
+//
+//	 AbortSCSICommand												[PROTECTED]
+//
+
+SCSIServiceResponse
 IOUSBMassStorageClass::AbortSCSICommand( SCSITaskIdentifier abortTask )
 {
  	IOReturn	status = kIOReturnSuccess;
@@ -623,7 +695,12 @@ IOUSBMassStorageClass::AbortSCSICommand( SCSITaskIdentifier abortTask )
 	// Since the driver currently does not support abort, return an error	
 	return kSCSIServiceResponse_FUNCTION_REJECTED;
 }
-    
+
+
+//
+//	 IsProtocolServiceSupported									[PROTECTED]
+//
+
 bool
 IOUSBMassStorageClass::IsProtocolServiceSupported( 
 										SCSIProtocolFeature 	feature, 
@@ -654,6 +731,11 @@ IOUSBMassStorageClass::IsProtocolServiceSupported(
 	return isSupported;
 }
 
+
+//
+//	 HandleProtocolServiceFeature									[PROTECTED]
+//
+
 bool
 IOUSBMassStorageClass::HandleProtocolServiceFeature( 
 										SCSIProtocolFeature 	feature, 
@@ -664,9 +746,16 @@ IOUSBMassStorageClass::HandleProtocolServiceFeature(
 
 
 #pragma mark -
-#pragma mark Standard USB Command Methods
+#pragma mark *** Standard USB Command Methods ***
+#pragma mark -
+
+
+//
+//	 ClearFeatureEndpointStall -	Method to do the CLEAR_FEATURE command for
+//									an ENDPOINT_STALL feature.		
+//																	[PROTECTED]
+//
 
-// Method to do the CLEAR_FEATURE command for an ENDPOINT_STALL feature.
 IOReturn 
 IOUSBMassStorageClass::ClearFeatureEndpointStall( 
 								IOUSBPipe *			thePipe,
@@ -706,8 +795,13 @@ IOUSBMassStorageClass::ClearFeatureEndpointStall(
 	return status;
 }
 
-// Method to do the GET_STATUS command for the endpoint that the
-// IOUSBPipe is connected to.
+
+//
+//	 GetStatusEndpointStatus -	Method to do the GET_STATUS command for the
+//								endpoint that the IOUSBPipe is connected to.		
+//																	[PROTECTED]
+//
+
 IOReturn 
 IOUSBMassStorageClass::GetStatusEndpointStatus( 
 								IOUSBPipe *			thePipe,
@@ -749,8 +843,19 @@ IOUSBMassStorageClass::GetStatusEndpointStatus(
 }
 
 #pragma mark -
-#pragma mark Accessor Methods For All Protocol Variables
+#pragma mark *** Accessor Methods For All Protocol Variables ***
+#pragma mark -
+
+
 /* The following methods are for use only by this class */
+
+
+//
+//	 GetInterfaceReference -	Method to do the GET_STATUS command for the
+//								endpoint that the IOUSBPipe is connected to.		
+//																	[PROTECTED]
+//
+
 IOUSBInterface *
 IOUSBMassStorageClass::GetInterfaceReference( void )
 {
@@ -763,24 +868,44 @@ IOUSBMassStorageClass::GetInterfaceReference( void )
 	return fInterface;
 }
 
+
+//
+//	 SetInterfaceReference											[PROTECTED]
+//
+
 void
 IOUSBMassStorageClass::SetInterfaceReference( IOUSBInterface * newInterface )
 {
 	fInterface = newInterface;
 }
 
+
+//
+//	 GetInterfaceSubClass											[PROTECTED]
+//
+
 UInt8
 IOUSBMassStorageClass::GetInterfaceSubclass( void )
 {
 	return fPreferredSubclass;
 }
 
+
+//
+//	 GetInterfaceProtocol											[PROTECTED]
+//
+
 UInt8
 IOUSBMassStorageClass::GetInterfaceProtocol( void )
 {
 	return fPreferredProtocol;
 }
 
+
+//
+//	 GetControlPipe												[PROTECTED]
+//
+
 IOUSBPipe *
 IOUSBMassStorageClass::GetControlPipe( void )
 {
@@ -792,18 +917,33 @@ IOUSBMassStorageClass::GetControlPipe( void )
 	return GetInterfaceReference()->GetDevice()->GetPipeZero();
 }
 
+
+//
+//	 GetBulkInPipe													[PROTECTED]
+//
+
 IOUSBPipe *
 IOUSBMassStorageClass::GetBulkInPipe( void )
 {
 	return fBulkInPipe;
 }
 
+
+//
+//	 GetBulkOutPipe												[PROTECTED]
+//
+
 IOUSBPipe *
 IOUSBMassStorageClass::GetBulkOutPipe( void )
 {
 	return fBulkOutPipe;
 }
 
+
+//
+//	 GetInterruptPipe												[PROTECTED]
+//
+
 IOUSBPipe *
 IOUSBMassStorageClass::GetInterruptPipe( void )
 {
@@ -811,7 +951,13 @@ IOUSBMassStorageClass::GetInterruptPipe( void )
 }
 
 #pragma mark -
-#pragma mark Accessor Methods For CBI Protocol Variables
+#pragma mark *** Accessor Methods For CBI Protocol Variables ***
+#pragma mark -
+
+
+//
+//	 GetCBIRequestBlock											[PROTECTED]
+//
 
 CBIRequestBlock *	
 IOUSBMassStorageClass::GetCBIRequestBlock( void )
@@ -820,6 +966,11 @@ IOUSBMassStorageClass::GetCBIRequestBlock( void )
 	return &fCBICommandRequestBlock;
 }
 
+
+//
+//	 ReleaseCBIRequestBlock										[PROTECTED]
+//
+
 void	
 IOUSBMassStorageClass::ReleaseCBIRequestBlock( CBIRequestBlock * cbiRequestBlock )
 {
@@ -832,7 +983,13 @@ IOUSBMassStorageClass::ReleaseCBIRequestBlock( CBIRequestBlock * cbiRequestBlock
 }
 
 #pragma mark -
-#pragma mark Accessor Methods For Bulk Only Protocol Variables
+#pragma mark *** Accessor Methods For Bulk Only Protocol Variables ***
+#pragma mark -
+
+
+//
+//	 GetBulkOnlyRequestBlock										[PROTECTED]
+//
 
 BulkOnlyRequestBlock *	
 IOUSBMassStorageClass::GetBulkOnlyRequestBlock( void )
@@ -841,6 +998,11 @@ IOUSBMassStorageClass::GetBulkOnlyRequestBlock( void )
 	return &fBulkOnlyCommandRequestBlock;
 }
 
+
+//
+//	 ReleaseBulkOnlyRequestBlock									[PROTECTED]
+//
+
 void	
 IOUSBMassStorageClass::ReleaseBulkOnlyRequestBlock( BulkOnlyRequestBlock * boRequestBlock )
 {
@@ -852,6 +1014,11 @@ IOUSBMassStorageClass::ReleaseBulkOnlyRequestBlock( BulkOnlyRequestBlock * boReq
 	return;
 }
 
+
+//
+//	 GetNextBulkOnlyCommandTag										[PROTECTED]
+//
+
 UInt32	
 IOUSBMassStorageClass::GetNextBulkOnlyCommandTag( void )
 {
@@ -860,7 +1027,11 @@ IOUSBMassStorageClass::GetNextBulkOnlyCommandTag( void )
 	return fBulkOnlyCommandTag;
 }
 
-// Will get called when a device has been resumed
+
+//
+//	 HandlePowerOn - Will get called when a device has been resumed   [PUBLIC]
+//
+
 IOReturn
 IOUSBMassStorageClass::HandlePowerOn( void )
 {
@@ -896,6 +1067,9 @@ IOUSBMassStorageClass::HandlePowerOn( void )
 		
 		// Reset the device on its own thread so we don't deadlock.
 		fResetInProgress = true;
+#if 0
+		retain();
+#endif
 		IOCreateThread( IOUSBMassStorageClass::sResetDevice, this );
 		fCommandGate->runAction ( ( IOCommandGate::Action ) &IOUSBMassStorageClass::sWaitForReset );
 		
@@ -905,6 +1079,10 @@ IOUSBMassStorageClass::HandlePowerOn( void )
 }
 
 
+//
+//	 handleOpen													   [PUBLIC]
+//
+
 bool
 IOUSBMassStorageClass::handleOpen( IOService *		client,
 								   IOOptionBits		options,
@@ -937,6 +1115,10 @@ ErrorExit:
 }
 
 
+//
+//	 handleClose													   [PUBLIC]
+//
+
 void
 IOUSBMassStorageClass::handleClose( IOService *		client,
 									IOOptionBits	options )
@@ -968,7 +1150,11 @@ Exit:
 	
 }
 
-	
+
+//
+//	 handleIsOpen													   [PUBLIC]
+//
+
 bool
 IOUSBMassStorageClass::handleIsOpen( const IOService * client ) const
 {
@@ -1002,6 +1188,10 @@ CallSuperClassError:
 }
 
 
+//
+//	 sWaitForReset											[STATIC][PROTECTED]
+//
+
 IOReturn
 IOUSBMassStorageClass::sWaitForReset( void * refcon )
 {
@@ -1011,6 +1201,10 @@ IOUSBMassStorageClass::sWaitForReset( void * refcon )
 }
 
 
+//
+//	 GatedWaitForReset												[PROTECTED]
+//
+
 IOReturn
 IOUSBMassStorageClass::GatedWaitForReset( void )
 {
@@ -1027,12 +1221,23 @@ IOUSBMassStorageClass::GatedWaitForReset( void )
 }
 
 
+//
+//	 sResetDevice											[STATIC][PROTECTED]
+//
+
 void
 IOUSBMassStorageClass::sResetDevice( void * refcon )
 {
 	IOUSBMassStorageClass *		driver;
 	driver = ( IOUSBMassStorageClass * ) refcon;
-	
+#if 0		
+	// Check if we should bail out because we are
+	// being terminated.
+	if ( driver->GetInterfaceReference() == NULL )
+	{
+		goto ErrorExit;
+	}
+#endif
 	driver->GetInterfaceReference()->GetDevice()->ResetDevice();
 	
 	if ( driver->GetBulkInPipe() != NULL )
@@ -1051,12 +1256,27 @@ IOUSBMassStorageClass::sResetDevice( void * refcon )
 	// Once the device has been reset, send notification to the client so that the
 	// device can be reconfigured for use.
 	driver->SendNotification_VerifyDeviceState();
+	
+#if 0
+ErrorExit:
+	
+	
+	driver->release();
+	
+	return;
+#endif	
 }
 
 
 OSMetaClassDefineReservedUsed( IOUSBMassStorageClass, 1 );
-// The recovery sequence to restore functionality for devices that
-// stop responding (like many devices after a Suspend/Resume).
+
+
+//
+//	 StartDeviceRecovery - The recovery sequence to restore functionality for
+//							devices that stop responding (like many devices
+//							after a Suspend/Resume).				[PROTECTED]
+//
+
 IOReturn
 IOUSBMassStorageClass::StartDeviceRecovery( void )
 {
@@ -1089,16 +1309,39 @@ IOUSBMassStorageClass::StartDeviceRecovery( void )
 
 OSMetaClassDefineReservedUsed( IOUSBMassStorageClass, 2 );
 
+
+//
+//	 FinishDeviceRecovery											[PROTECTED]
+//
+
 void
 IOUSBMassStorageClass::FinishDeviceRecovery( IOReturn status )
 {
+#if 0
+	SCSITaskIdentifier	tempTask = NULL;
+#endif
 	if ( status != kIOReturnSuccess)
 	{
 		// The endpoint status could not be retrieved meaning that the device has
 		// stopped responding.  Begin the device reset sequence.
 		
 		STATUS_LOG(("%s: StartDeviceRecovery GetStatusEndpointStatus error.\n", getName() ));
-	
+#if 0		
+		if ( GetInterfaceReference() == NULL )
+		{
+			// We are being terminated.  We should clean up and bail...
+			if( fBulkOnlyCommandStructInUse == true )
+			{
+				tempTask = fBulkOnlyCommandRequestBlock.request;
+			}
+			else if ( fCBICommandStructInUse == true )
+			{
+				tempTask = fCBICommandRequestBlock.request;
+			}
+			
+			goto ErrorExit;
+		}
+#endif		
 		status = (GetInterfaceReference()->GetDevice())->ResetDevice();
 		
 		// Once the device has been reset, send notification to the client so that the
@@ -1109,8 +1352,10 @@ IOUSBMassStorageClass::FinishDeviceRecovery( IOReturn status )
 	// If the device is responding correctly or has been reset, retry the command.
 	if( status == kIOReturnSuccess )
 	{
+
+// Remove me start
 		SCSITaskIdentifier	tempTask = NULL;
-		
+// Remove me end
 		if( fBulkOnlyCommandStructInUse == true )
 		{
 			tempTask = fBulkOnlyCommandRequestBlock.request;
@@ -1122,7 +1367,12 @@ IOUSBMassStorageClass::FinishDeviceRecovery( IOReturn status )
 	   			 		status));
 			if( status != kIOReturnSuccess)
 			{
+// Remove me start
 				RejectTask( tempTask );
+//Remove me end
+#if 0
+				goto ErrorExit;
+#endif
 			}
 		}
 		else if ( fCBICommandStructInUse == true )
@@ -1135,12 +1385,33 @@ IOUSBMassStorageClass::FinishDeviceRecovery( IOReturn status )
 	   					status));
 			if( status != kIOReturnSuccess)
 			{
+// Remove me start
 				RejectTask( tempTask );
+//Remove me end
+#if 0
+				goto ErrorExit;
+#endif
 			}
 	   	}
 	}
+
+#if 0	
+	return;
+	
+ErrorExit:
+	
+	if ( tempTask != NULL )
+	{
+		RejectTask( tempTask );
+	}
+#endif
 }
 
+
+//
+//	 DeviceRecoveryCompletionAction								[PROTECTED]
+//
+
 void 
 IOUSBMassStorageClass::DeviceRecoveryCompletionAction(
 					                void *			target,
