@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2001 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
@@ -25,14 +25,14 @@
 
 // This class' header file
 #include <IOKit/usb/IOUSBMassStorageClass.h>
-#include <IOKit/scsi-commands/SCSICommandDefinitions.h>
+#include <IOKit/scsi-commands/IOSCSIPrimaryCommandsDevice.h>
 
 #pragma mark -
-#pragma mark IOUSBMassStorageUFISubclass definition
+#pragma mark IOUSBMassStorageUFIDevice declaration
 
-class IOUSBMassStorageUFISubclass : public IOUSBMassStorageClass
+class IOUSBMassStorageUFIDevice : public IOSCSIPrimaryCommandsDevice
 {
-    OSDeclareDefaultStructors(IOUSBMassStorageUFISubclass)
+    OSDeclareDefaultStructors(IOUSBMassStorageUFIDevice)
 
 private:
 	static void			AsyncReadWriteComplete( SCSITaskIdentifier	completedTask );
@@ -43,13 +43,12 @@ private:
 	
 protected:
     // Reserve space for future expansion.
-    struct IOUSBMassStorageUFISubclassExpansionData
+    struct IOUSBMassStorageUFIDeviceExpansionData
 	{
-		IONotifier *	fKeySwitchNotifier;
 	};
-    IOUSBMassStorageUFISubclassExpansionData *fIOUSBMassStorageUFISubclassReserved;
+    IOUSBMassStorageUFIDeviceExpansionData *fIOUSBMassStorageUFIDeviceReserved;
 	
-	#define fKeySwitchNotifier fIOUSBMassStorageUFISubclassReserved->fKeySwitchNotifier	
+	IONotifier *		fKeySwitchNotifier;
 	
 	// ---- Medium Characteristics ----
 	bool				fMediumPresent;
@@ -74,14 +73,13 @@ protected:
 	};
 
 	OSDictionary * 		fDeviceCharacteristicsDictionary;
-
-	virtual	bool		BeginProvidedServices( void );
-	virtual	bool		EndProvidedServices( void );
-
+	
 	// ---- Methods for controlling the current state of device support ----
 	virtual bool		InitializeDeviceSupport( void );
+	virtual void 		StartDeviceSupport ( void );
 	virtual void		SuspendDeviceSupport( void );
 	virtual void		ResumeDeviceSupport( void );
+	virtual void 		StopDeviceSupport ( void );
 	virtual void		TerminateDeviceSupport( void );
 
 	// ---- Methods used for misc  ----
@@ -94,7 +92,7 @@ protected:
 	virtual void		EnablePolling( void );
 	virtual void		DisablePolling( void );
 
-	// Main and support methods for polling for new Media
+	// ---- Main and support methods for polling for new Media ----
 	virtual void		PollForNewMedia( void );
 	virtual bool		DetermineMediaPresence( void );
 	virtual bool		DetermineMediumCapacity( 
@@ -102,8 +100,15 @@ protected:
 							UInt64 * 				blockCount );
 	virtual bool		DetermineMediumWriteProtectState( void );
 
-	// Main and support methods for polling for Media removal
+	// ---- Main and support methods for polling for Media removal ----
 	virtual void		PollForMediaRemoval( void );
+	
+	// ---- Methods used for power managment ----
+	virtual UInt32		GetInitialPowerState ( void );
+	virtual void		HandlePowerChange ( void );
+	virtual void		HandleCheckPowerState ( void );
+	virtual void		TicklePowerManager ( void );
+	virtual UInt32		GetNumberOfPowerStateTransitions ( void );
 
 	// ---- Methods used for handling medium characteristics ----
     virtual void		SetMediumCharacteristics( 
@@ -135,92 +140,6 @@ protected:
                       		UInt64					blockCount,
 							void * 					clientData );
 
-	// This will get a new SCSITask for the caller
-	virtual SCSITaskIdentifier		GetSCSITask ( void );
-	
-	// This will release a SCSITask (eventually return it to a pool)
-	virtual void					ReleaseSCSITask ( SCSITaskIdentifier request );
-
-	// Call for executing the command synchronously	
-	SCSIServiceResponse 			SendCommand ( 	
-										SCSITaskIdentifier 	request,
-										UInt32 				timeoutDuration );
-														
-	static void		TaskCallback ( SCSITaskIdentifier completedTask );
-	
-	// Call for executing the command asycnchronously	
-	void 							SendCommand ( 
-										SCSITaskIdentifier 	request,
-										UInt32 				timeoutDuration,
-										SCSITaskCompletion 	taskCompletion );
-
-	bool							SetTaskAttribute ( 
-										SCSITaskIdentifier 		request, 
-										SCSITaskAttribute 		newAttribute );
-	SCSITaskAttribute				GetTaskAttribute ( 
-										SCSITaskIdentifier 		request );
-	bool							SetTaskState ( 	
-										SCSITaskIdentifier 		request,
-										SCSITaskState 			newTaskState );
-	SCSITaskState					GetTaskState ( 
-										SCSITaskIdentifier 		request );
-	bool							SetTaskStatus ( 
-										SCSITaskIdentifier 		request, 
-										SCSITaskStatus 			newStatus );
-	SCSITaskStatus					GetTaskStatus ( 
-										SCSITaskIdentifier 		request );
-	bool							SetDataTransferDirection ( 
-										SCSITaskIdentifier 		request, 
-										UInt8 					newDirection );
-	UInt8							GetDataTransferDirection ( 
-										SCSITaskIdentifier 		request );
-	bool							SetRequestedDataTransferCount (
-										SCSITaskIdentifier 		request, 
-										UInt64 					newRequestedCount );
-	UInt64							GetRequestedDataTransferCount (
-										SCSITaskIdentifier 		request );
-	bool							SetRealizedDataTransferCount (
-										SCSITaskIdentifier 		request,
-										UInt64 					newRealizedDataCount );
-	UInt64							GetRealizedDataTransferCount( 
-										SCSITaskIdentifier 		request );
-	bool							SetDataBuffer( 
-										SCSITaskIdentifier 		request, 
-										IOMemoryDescriptor * 	newBuffer );
-	IOMemoryDescriptor *			GetDataBuffer( 
-										SCSITaskIdentifier 		request );
-	bool							SetTimeoutDuration( 
-										SCSITaskIdentifier 		request, 
-										UInt32 					newTimeout );
-	UInt32							GetTimeoutDuration( 
-										SCSITaskIdentifier 		request );
-	bool							SetTaskCompletionCallback( 
-										SCSITaskIdentifier 		request,
-										SCSITaskCompletion 		newCallback );
-	void							TaskCompletedNotification ( 
-										SCSITaskIdentifier 		request );
-
-	bool							SetServiceResponse( 
-										SCSITaskIdentifier 		request,
-										SCSIServiceResponse 	serviceResponse );
-	SCSIServiceResponse 			GetServiceResponse( 
-										SCSITaskIdentifier 		request );
-	bool							SetAutosenseCommand(
-										SCSITaskIdentifier 		request,
-										UInt8					cdbByte0,
-										UInt8					cdbByte1,
-										UInt8					cdbByte2,
-										UInt8					cdbByte3,
-										UInt8					cdbByte4,
-										UInt8					cdbByte5 );
-	bool							GetAutoSenseData( 	
-										SCSITaskIdentifier 		request,
-										SCSI_Sense_Data * 		senseData );
-	bool							SetApplicationLayerReference( 
-										SCSITaskIdentifier 		request,
-										void * 					newReferenceValue );
-	void *							GetApplicationLayerReference( 
-										SCSITaskIdentifier 		request );
 public:
 	virtual void		free ( void );
 	
@@ -297,35 +216,6 @@ protected:
 							SCSICmdField4Byte 			param,
 							SCSICmdField4Byte 			mask );
 	
-	bool		 	IsBufferAndCapacityValid(
-							IOMemoryDescriptor *		dataBuffer,
-							UInt32 						requiredSize );
-	
-	// ----- Methods for accessing the SCSITask ----------
-	// Populate the 12 Byte Command Descriptor Block
-	bool 	SetCommandDescriptorBlock (
-							SCSITask *					request,
-							UInt8						cdbByte0,
-							UInt8						cdbByte1,
-							UInt8						cdbByte2,
-							UInt8						cdbByte3,
-							UInt8						cdbByte4,
-							UInt8						cdbByte5,
-							UInt8						cdbByte6 = 0,
-							UInt8						cdbByte7 = 0,
-							UInt8						cdbByte8 = 0,
-							UInt8						cdbByte9 = 0,
-							UInt8						cdbByte10 = 0,
-							UInt8						cdbByte11 = 0 );
-
-	// Set up the control information for the transfer, including
-	// the transfer direction and the number of bytes to transfer.
-	bool	SetDataTransferControl(
-							SCSITask *					request,
-							UInt8						dataTransferDirection,
-							IOMemoryDescriptor *		dataBuffer = NULL,
-							UInt64						transferCountInBytes = 0 );
-
 	// UFI Required Commands
 	virtual bool 	FORMAT_UNIT(
 							SCSITaskIdentifier			request,
@@ -458,4 +348,17 @@ protected:
 			    			SCSICmdField2Byte 			TRANSFER_LENGTH );
 };
 
+
+#pragma mark -
+#pragma mark IOUSBMassStorageUFISubclass declaration
+
+class IOUSBMassStorageUFISubclass : public IOUSBMassStorageClass
+{
+    OSDeclareDefaultStructors(IOUSBMassStorageUFISubclass)
+
+protected:
+	virtual	bool		BeginProvidedServices( void );
+	virtual	bool		EndProvidedServices( void );
+};
+
 #endif _IOKIT_IOUSBMASSSTORAGEUFISUBCLASS_H
