@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2001 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
@@ -20,8 +20,17 @@
  * @APPLE_LICENSE_HEADER_END@
  */
 
+//
+//	Includes
+//
+
 #include <IOKit/usb/IOUSBMassStorageClass.h>
 
+
+//
+//	Macros
+//
+
 // Macros for printing debugging information
 #if (USB_MASS_STORAGE_DEBUG == 1)
 #define STATUS_LOG(x)	IOLog x
@@ -45,7 +54,13 @@ enum
 #pragma mark -
 #pragma mark Protocol Services Methods
 
-// The AbortSCSICommand helper method for CBI and CB protocol devices.
+
+//
+//	 AbortSCSICommandForCBIProtocol -	The AbortSCSICommand helper method for
+//										CBI and CB protocol devices.
+//																	[PROTECTED]
+//
+
 IOReturn 
 IOUSBMassStorageClass::AbortSCSICommandForCBIProtocol(
 							SCSITaskIdentifier abortTask )
@@ -53,7 +68,13 @@ IOUSBMassStorageClass::AbortSCSICommandForCBIProtocol(
 	return kIOReturnError;
 }
 
-// The SendSCSICommand helper method for CBI and CB protocol devices.
+
+//
+//	 SendSCSICommandForCBIProtocol -	The SendSCSICommand helper method for
+//										CBI and CB protocol devices.
+//																	[PROTECTED]
+//
+
 IOReturn 
 IOUSBMassStorageClass::SendSCSICommandForCBIProtocol( SCSITaskIdentifier request )
 {
@@ -111,6 +132,11 @@ IOUSBMassStorageClass::SendSCSICommandForCBIProtocol( SCSITaskIdentifier request
 #pragma mark -
 #pragma mark SendSCSICommand Helper methods
 
+
+//
+//	 CBIProtocolUSBCompletionAction								[PROTECTED]
+//
+
 void 
 IOUSBMassStorageClass::CBIProtocolUSBCompletionAction(
 					                void *			target,
@@ -128,6 +154,11 @@ IOUSBMassStorageClass::CBIProtocolUSBCompletionAction(
 											bufferSizeRemaining );
 }
 
+
+//
+//	 CBIProtocolTransferData										[PROTECTED]
+//
+
 IOReturn 
 IOUSBMassStorageClass::CBIProtocolTransferData( 
 						CBIRequestBlock *		cbiRequestBlock,
@@ -145,6 +176,9 @@ IOUSBMassStorageClass::CBIProtocolTransferData(
 					GetDataBuffer( cbiRequestBlock->request ), 
 					GetTimeoutDuration( cbiRequestBlock->request ),  // Use the client's timeout for both
 					GetTimeoutDuration( cbiRequestBlock->request ),
+#if 0
+					GetRequestedDataTransferCount( cbiRequestBlock->request ),
+#endif
 					&cbiRequestBlock->cbiCompletion );
 	}
 	else if (GetDataTransferDirection(cbiRequestBlock->request) == kSCSIDataTransfer_FromInitiatorToTarget)
@@ -153,6 +187,9 @@ IOUSBMassStorageClass::CBIProtocolTransferData(
 					GetDataBuffer( cbiRequestBlock->request ), 
 					GetTimeoutDuration( cbiRequestBlock->request ),  // Use the client's timeout for both
 					GetTimeoutDuration( cbiRequestBlock->request ),
+#if 0
+					GetRequestedDataTransferCount( cbiRequestBlock->request ),
+#endif
 					&cbiRequestBlock->cbiCompletion );
 	}
 
@@ -163,6 +200,10 @@ IOUSBMassStorageClass::CBIProtocolTransferData(
 }
 
 
+//
+//	 CBIProtocolReadInterrupt										[PROTECTED]
+//
+
 IOReturn 
 IOUSBMassStorageClass::CBIProtocolReadInterrupt( 
 						CBIRequestBlock *		cbiRequestBlock,
@@ -193,6 +234,11 @@ IOUSBMassStorageClass::CBIProtocolReadInterrupt(
 	return status;
 }
 
+
+//
+//	 CBIGetStatusEndpointStatus									[PROTECTED]
+//
+
 IOReturn 
 IOUSBMassStorageClass::CBIGetStatusEndpointStatus( 
 						IOUSBPipe *				targetPipe,
@@ -212,6 +258,11 @@ IOUSBMassStorageClass::CBIGetStatusEndpointStatus(
 	return status;
 }
 
+
+//
+//	 CBIClearFeatureEndpointStall									[PROTECTED]
+//
+
 IOReturn 
 IOUSBMassStorageClass::CBIClearFeatureEndpointStall( 
 						IOUSBPipe *				targetPipe,
@@ -232,6 +283,10 @@ IOUSBMassStorageClass::CBIClearFeatureEndpointStall(
 }
 
 
+//
+//	 CBIProtocolCommandCompletion									[PROTECTED]
+//
+
 void 
 IOUSBMassStorageClass::CBIProtocolCommandCompletion(
 						CBIRequestBlock *		cbiRequestBlock,
